@@ -5,8 +5,8 @@ Created on Mon Dec 25 22:28:49 2017
 
 @author: albintveitankappi
 """
-import escapetheforest.items
-import escapetheforest.tiles
+import items
+import tiles
 
 # Things to fix:
 # LeaveForrestTile cant be in the middle of the forrest, thats silly! But then again, the person playing the game 
@@ -17,7 +17,7 @@ import escapetheforest.tiles
 # Im thinking its time to introduce an NPC that its possible to hold a conversation with! An old man in a hut? 
 # A troll, at first appearing to be a stone?
 
-import escapetheforest.world
+import world
 from escapetheforest.player import Player
 
 def play():
@@ -70,7 +70,8 @@ def play():
            
 
 if __name__ == "__main__":
-    import escapetheforest.items
-    import escapetheforest.world
-    from escapetheforest.player import Player
+    import escapetheforest.items as items
+    import escapetheforest.world as world
+    import escapetheforest.player as player
+    from player import Player
     play()
